Qulacs: Main Page

- Main Page
- Related Pages
- Namespaces
- Classes
- Files

Qulacs Documentation

#### Qulacs is super-fast quantum circuit simulator for simulating large, noisy or parametric quantum circuits.
Implemented in C/C++ and with python interface, Qulacs achieved both high speed circuit simulation and high usability.
We welcome quantum information researcher to use Qulacs!
Qulacs was developed in Professor Fujii's group. Maintained and developing new features by QunaSys.

### GitHub

### Slack Community

### Study Material (Japanese)